package cz.moneta.test.dsl.util.task.brokerportal;

import cz.moneta.test.dsl.Harness;

public class BrokerPortalTasks {

    private final Harness harness;

    public BrokerPortalTasks(Harness harness) { this.harness = harness; }

    public LoginTasks loginTasks() { return new LoginTasks(harness); }

    public CalculatorTasks calculatorTasks() { return new CalculatorTasks(harness); }

    public ShortApplicationTasks shortApplicationTasks() { return new ShortApplicationTasks(harness); }

    public FullApplicationTasks fullApplicationTasks() { return new FullApplicationTasks(harness); }

    public CommonTasks commonTasks() { return new CommonTasks(harness); }

    public ContractDetailTasks contractDetailTasks() { return new ContractDetailTasks(harness); }

    public MenuTasks menuTasks() { return new MenuTasks(harness); }

    public ValuationTasks brokerPortalValuations() { return new ValuationTasks(harness); }
}